@@ -131,6 +131,10 @@ KNOWN_EXTRA_OUTPUT_KEYS = [
     'xray.GetTraceSummaries.TracesProcessedCount',
     'xray.GetTraceSummaries.ApproximateTime',
 ]
+KNOWN_PAGINATORS_WITH_INTEGER_OUTPUTS = (
+    ('dynamodb', 'Query'),
+    ('dynamodb', 'Scan'),
+)
 
 
 def _pagination_configs():
@@ -150,11 +154,12 @@ def _pagination_configs():
 )
 def test_lint_pagination_configs(operation_name, page_config, service_model):
     _validate_known_pagination_keys(page_config)
-    _valiate_result_key_exists(page_config)
+    _validate_result_key_exists(page_config)
     _validate_referenced_operation_exists(operation_name, service_model)
     _validate_operation_has_output(operation_name, service_model)
     _validate_input_keys_match(operation_name, page_config, service_model)
     _validate_output_keys_match(operation_name, page_config, service_model)
+    _validate_new_numeric_keys(operation_name, page_config, service_model)
 
 
 def _validate_known_pagination_keys(page_config):
@@ -165,7 +170,7 @@ def _validate_known_pagination_keys(page_config):
             )
 
 
-def _valiate_result_key_exists(page_config):
+def _validate_result_key_exists(page_config):
     if 'result_key' not in page_config:
         raise AssertionError(
             "Required key 'result_key' is missing "
@@ -260,6 +265,30 @@ def _validate_output_keys_match(operation_name, page_config, service_model):
         )
 
 
+def _validate_new_numeric_keys(operation_name, page_config, service_model):
+    output_shape = service_model.operation_model(operation_name).output_shape
+    for key in _get_list_value(page_config, 'result_key'):
+        current_shape = output_shape
+        if '.' in key:  # result_key is a JMESPath expression
+            for part in key.split('.'):
+                current_shape = current_shape.members[part]
+        elif key in output_shape.members:
+            current_shape = output_shape.members[key]
+
+        if (
+            getattr(current_shape, 'type_name', None) == 'integer'
+            and (service_model.service_name, operation_name)
+            not in KNOWN_PAGINATORS_WITH_INTEGER_OUTPUTS
+        ):
+            raise AssertionError(
+                f'There is a new operation {operation_name} for service '
+                f'{service_model.service_name} that is configured to sum '
+                'integer outputs across pages. Verify that this behavior is '
+                'correct before allow-listing, since whether or not it is '
+                'appropriate to sum depends on the subject matter.'
+            )
+
+
 def _looks_like_jmespath(expression):
     if all(ch in MEMBER_NAME_CHARS for ch in expression):
         return False
