@@ -17,8 +17,8 @@ import time
 from concurrent.futures import Future
 
 from botocore.session import Session
-
 from s3transfer.subscribers import BaseSubscriber
+
 from tests import (
     HAS_CRT,
     FileCreator,
@@ -31,7 +31,6 @@ from tests import (
 
 if HAS_CRT:
     import awscrt
-
     import s3transfer.crt
 
 
@@ -69,7 +68,9 @@ class TestCRTTransferManager(unittest.TestCase):
         self.region = 'us-west-2'
         self.bucket = "test_bucket"
         self.s3express_bucket = 's3expressbucket--usw2-az5--x-s3'
-        self.mrap_accesspoint = 'arn:aws:s3::123456789012:accesspoint/mfzwi23gnjvgw.mrap'
+        self.mrap_accesspoint = (
+            'arn:aws:s3::123456789012:accesspoint/mfzwi23gnjvgw.mrap'
+        )
         self.mrap_bucket = 'mfzwi23gnjvgw.mrap'
         self.key = "test_key"
         self.expected_content = b'my content'
@@ -79,12 +80,12 @@ class TestCRTTransferManager(unittest.TestCase):
             'myfile', self.expected_content, mode='wb'
         )
         self.expected_path = "/" + self.bucket + "/" + self.key
-        self.expected_host = "s3.%s.amazonaws.com" % (self.region)
-        self.expected_s3express_host = (
-            f'{self.s3express_bucket}.s3express-usw2-az5.us-west-2.amazonaws.com'
-        )
+        self.expected_host = f"s3.{self.region}.amazonaws.com"
+        self.expected_s3express_host = f'{self.s3express_bucket}.s3express-usw2-az5.us-west-2.amazonaws.com'
         self.expected_s3express_path = f'/{self.key}'
-        self.expected_mrap_host = f'{self.mrap_bucket}.accesspoint.s3-global.amazonaws.com'
+        self.expected_mrap_host = (
+            f'{self.mrap_bucket}.accesspoint.s3-global.amazonaws.com'
+        )
         self.expected_mrap_path = f"/{self.key}"
         self.s3_request = mock.Mock(awscrt.s3.S3Request)
         self.s3_crt_client = mock.Mock(awscrt.s3.S3Client)
@@ -145,9 +146,7 @@ class TestCRTTransferManager(unittest.TestCase):
                 self.assertNotIn(expected_missing_header.lower(), header_names)
 
     def _assert_expected_s3express_request(
-        self,
-        make_request_kwargs,
-        expected_http_method='GET'
+        self, make_request_kwargs, expected_http_method='GET'
     ):
         self._assert_expected_crt_http_request(
             make_request_kwargs["request"],
@@ -158,7 +157,7 @@ class TestCRTTransferManager(unittest.TestCase):
         self.assertIn('signing_config', make_request_kwargs)
         self.assertEqual(
             make_request_kwargs['signing_config'].algorithm,
-            awscrt.auth.AwsSigningAlgorithm.V4_S3EXPRESS
+            awscrt.auth.AwsSigningAlgorithm.V4_S3EXPRESS,
         )
         self.assertFalse(
             make_request_kwargs['signing_config'].use_double_uri_encode,
@@ -168,9 +167,7 @@ class TestCRTTransferManager(unittest.TestCase):
         )
 
     def _assert_expected_mrap_request(
-        self,
-        make_request_kwargs,
-        expected_http_method='GET'
+        self, make_request_kwargs, expected_http_method='GET'
     ):
         self._assert_expected_crt_http_request(
             make_request_kwargs["request"],
@@ -181,11 +178,9 @@ class TestCRTTransferManager(unittest.TestCase):
         self.assertIn('signing_config', make_request_kwargs)
         self.assertEqual(
             make_request_kwargs['signing_config'].algorithm,
-            awscrt.auth.AwsSigningAlgorithm.V4_ASYMMETRIC
-        )
-        self.assertEqual(
-            make_request_kwargs['signing_config'].region, "*"
+            awscrt.auth.AwsSigningAlgorithm.V4_ASYMMETRIC,
         )
+        self.assertEqual(make_request_kwargs['signing_config'].region, "*")
         self.assertFalse(
             make_request_kwargs['signing_config'].use_double_uri_encode,
         )
@@ -416,24 +411,30 @@ class TestCRTTransferManager(unittest.TestCase):
 
     def test_upload_with_s3express(self):
         future = self.transfer_manager.upload(
-            self.filename, self.s3express_bucket, self.key, {},
-            [self.record_subscriber]
+            self.filename,
+            self.s3express_bucket,
+            self.key,
+            {},
+            [self.record_subscriber],
         )
         future.result()
         self._assert_expected_s3express_request(
             self.s3_crt_client.make_request.call_args[1],
-            expected_http_method='PUT'
+            expected_http_method='PUT',
         )
 
     def test_upload_with_mrap(self):
         future = self.transfer_manager.upload(
-            self.filename, self.mrap_accesspoint, self.key, {},
-            [self.record_subscriber]
+            self.filename,
+            self.mrap_accesspoint,
+            self.key,
+            {},
+            [self.record_subscriber],
         )
         future.result()
         self._assert_expected_mrap_request(
             self.s3_crt_client.make_request.call_args[1],
-            expected_http_method='PUT'
+            expected_http_method='PUT',
         )
 
     def test_upload_with_full_checksum(self):
@@ -571,24 +572,30 @@ class TestCRTTransferManager(unittest.TestCase):
 
     def test_download_with_s3express(self):
         future = self.transfer_manager.download(
-            self.s3express_bucket, self.key, self.filename, {},
-            [self.record_subscriber]
+            self.s3express_bucket,
+            self.key,
+            self.filename,
+            {},
+            [self.record_subscriber],
         )
         future.result()
         self._assert_expected_s3express_request(
             self.s3_crt_client.make_request.call_args[1],
-            expected_http_method='GET'
+            expected_http_method='GET',
         )
 
     def test_download_with_mrap(self):
         future = self.transfer_manager.download(
-            self.mrap_accesspoint, self.key, self.filename, {},
-            [self.record_subscriber]
+            self.mrap_accesspoint,
+            self.key,
+            self.filename,
+            {},
+            [self.record_subscriber],
         )
         future.result()
         self._assert_expected_mrap_request(
             self.s3_crt_client.make_request.call_args[1],
-            expected_http_method='GET'
+            expected_http_method='GET',
         )
 
     def test_delete(self):
@@ -622,7 +629,7 @@ class TestCRTTransferManager(unittest.TestCase):
         future.result()
         self._assert_expected_s3express_request(
             self.s3_crt_client.make_request.call_args[1],
-            expected_http_method='DELETE'
+            expected_http_method='DELETE',
         )
 
     def test_blocks_when_max_requests_processes_reached(self):
